# Flaura
Merge upstream with ease!

Flaura implements all the merging behaviors of Git, and not only that, it's Git-ndependent, or standalone, which makes merging a non-Git folder, or just a certain folder in a Git repository, instead of the whole repository. 

It allows hardforking to be like a charm!!

## Project Status
At the moment, Flaura is still in early development. 

No commands have been implemented except `flaura merge` and `flaura init`. 

`flaura merge` should be the basic functionality of Flaura for it to be useful, even though the UX is lacking!! You can see its documentation with `flaura merge --help`